@@ -153,25 +153,25 @@ as_datetimeoffset.clock_year_month_day <- function(x, ...) {
 #' @rdname as_datetimeoffset
 #' @export
 as_datetimeoffset.clock_year_month_weekday <- function(x, ...) {
-    as_datetimeoffset(plus_format(as_year_month_day(x)))
+    as_datetimeoffset(plus_format(clock::as_year_month_day(x)))
 }
 
 #' @rdname as_datetimeoffset
 #' @export
 as_datetimeoffset.clock_iso_year_week_day <- function(x, ...) {
-    as_datetimeoffset(plus_format(as_year_month_day(x)))
+    as_datetimeoffset(plus_format(clock::as_year_month_day(x)))
 }
 
 #' @rdname as_datetimeoffset
 #' @export
 as_datetimeoffset.clock_year_quarter_day <- function(x, ...) {
-    as_datetimeoffset(plus_format(as_year_month_day(x)))
+    as_datetimeoffset(plus_format(clock::as_year_month_day(x)))
 }
 
 #' @rdname as_datetimeoffset
 #' @export
 as_datetimeoffset.clock_year_day <- function(x, ...) {
-    as_datetimeoffset(plus_format(as_year_month_day(x)))
+    as_datetimeoffset(plus_format(clock::as_year_month_day(x)))
 }
 
 #' @rdname as_datetimeoffset
